@@ -69,7 +69,7 @@ class Rss extends AbstractFeed
             return $authors[$index];
         }
 
-        return null;
+        return;
     }
 
     /**
@@ -106,8 +106,6 @@ class Rss extends AbstractFeed
         if ($list->length) {
             foreach ($list as $author) {
                 $string = trim($author->nodeValue);
-                $email = null;
-                $name = null;
                 $data = array();
                 // Pretty rough parsing - but it's a catchall
                 if (preg_match("/^.*@[^ ]*/", $string, $matches)) {
@@ -194,7 +192,6 @@ class Rss extends AbstractFeed
             return $this->data['datemodified'];
         }
 
-        $dateModified = null;
         $date = null;
 
         if ($this->getType() !== Reader\Reader::TYPE_RSS_10 &&
@@ -258,7 +255,6 @@ class Rss extends AbstractFeed
             return $this->data['lastBuildDate'];
         }
 
-        $lastBuildDate = null;
         $date = null;
 
         if ($this->getType() !== Reader\Reader::TYPE_RSS_10 &&
@@ -310,8 +306,6 @@ class Rss extends AbstractFeed
             return $this->data['description'];
         }
 
-        $description = null;
-
         if ($this->getType() !== Reader\Reader::TYPE_RSS_10 &&
             $this->getType() !== Reader\Reader::TYPE_RSS_090) {
             $description = $this->xpath->evaluate('string(/rss/channel/description)');
@@ -481,8 +475,6 @@ class Rss extends AbstractFeed
             return $this->data['link'];
         }
 
-        $link = null;
-
         if ($this->getType() !== Reader\Reader::TYPE_RSS_10 &&
             $this->getType() !== Reader\Reader::TYPE_RSS_090) {
             $link = $this->xpath->evaluate('string(/rss/channel/link)');
@@ -514,8 +506,6 @@ class Rss extends AbstractFeed
             return $this->data['feedlink'];
         }
 
-        $link = null;
-
         $link = $this->getExtension('Atom')->getFeedLink();
 
         if ($link === null || empty($link)) {
@@ -578,8 +568,6 @@ class Rss extends AbstractFeed
             return $this->data['title'];
         }
 
-        $title = null;
-
         if ($this->getType() !== Reader\Reader::TYPE_RSS_10 &&
             $this->getType() !== Reader\Reader::TYPE_RSS_090) {
             $title = $this->xpath->evaluate('string(/rss/channel/title)');
