@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
@@ -129,13 +129,12 @@ class Form extends Fieldset implements FormInterface
      */
     protected $validationGroup;
 
-
     /**
      * Set options for a form. Accepted options are:
      * - prefer_form_input_filter: is form input filter is preferred?
      *
      * @param  array|Traversable $options
-     * @return Element|ElementInterface
+     * @return self
      * @throws Exception\InvalidArgumentException
      */
     public function setOptions($options)
@@ -164,7 +163,7 @@ class Form extends Fieldset implements FormInterface
      *
      * @param  array|Traversable|ElementInterface $elementOrFieldset
      * @param  array                              $flags
-     * @return \Zend\Form\Fieldset|\Zend\Form\FieldsetInterface|\Zend\Form\FormInterface
+     * @return self
      */
     public function add($elementOrFieldset, array $flags = array())
     {
@@ -193,7 +192,7 @@ class Form extends Fieldset implements FormInterface
      * available, and prepares any elements and/or fieldsets that require
      * preparation.
      *
-     * @return Form
+     * @return self
      */
     public function prepare()
     {
@@ -231,7 +230,7 @@ class Form extends Fieldset implements FormInterface
     {
         $name = $this->getName();
 
-        foreach ($this->byName as $elementOrFieldset) {
+        foreach ($this->iterator as $elementOrFieldset) {
             if ($form->wrapElements()) {
                 $elementOrFieldset->setName($name . '[' . $elementOrFieldset->getName() . ']');
             }
@@ -249,7 +248,7 @@ class Form extends Fieldset implements FormInterface
      * Typically, also passes data on to the composed input filter.
      *
      * @param  array|\ArrayAccess|Traversable $data
-     * @return Form|FormInterface
+     * @return self
      * @throws Exception\InvalidArgumentException
      */
     public function setData($data)
@@ -279,7 +278,7 @@ class Form extends Fieldset implements FormInterface
      *
      * @param  object $object
      * @param  int $flags
-     * @return mixed|void
+     * @return self
      * @throws Exception\InvalidArgumentException
      */
     public function bind($object, $flags = FormInterface::VALUES_NORMALIZED)
@@ -300,7 +299,10 @@ class Form extends Fieldset implements FormInterface
 
         $this->bindAs = $flags;
         $this->setObject($object);
-        $this->extract();
+
+        $data = $this->extract();
+
+        $this->populateValues($data, true);
 
         return $this;
     }
@@ -393,7 +395,7 @@ class Form extends Fieldset implements FormInterface
      * Set flag indicating whether or not to bind values on successful validation
      *
      * @param  int $bindOnValidateFlag
-     * @return void|Form
+     * @return self
      * @throws Exception\InvalidArgumentException
      */
     public function setBindOnValidate($bindOnValidateFlag)
@@ -426,7 +428,7 @@ class Form extends Fieldset implements FormInterface
      * Set the base fieldset to use when hydrating
      *
      * @param  FieldsetInterface $baseFieldset
-     * @return Form
+     * @return self
      * @throws Exception\InvalidArgumentException
      */
     public function setBaseFieldset(FieldsetInterface $baseFieldset)
@@ -480,6 +482,7 @@ class Form extends Fieldset implements FormInterface
 
         if (!is_array($this->data)) {
             $data = $this->extract();
+            $this->populateValues($data, true);
             if (!is_array($data)) {
                 throw new Exception\DomainException(sprintf(
                     '%s is unable to validate as there is no data currently set',
@@ -558,7 +561,7 @@ class Form extends Fieldset implements FormInterface
      * Typically, proxies to the composed input filter
      *
      * @throws Exception\InvalidArgumentException
-     * @return Form|FormInterface
+     * @return self
      */
     public function setValidationGroup()
     {
@@ -617,11 +620,11 @@ class Form extends Fieldset implements FormInterface
                 continue;
             }
 
-            $fieldset = $formOrFieldset->byName[$key];
+            $fieldset = $formOrFieldset->iterator->get($key);
 
             if ($fieldset instanceof Collection) {
                 if (!isset($data[$key]) && $fieldset->getCount() == 0) {
-                    unset ($validationGroup[$key]);
+                    unset($validationGroup[$key]);
                     continue;
                 }
 
@@ -647,7 +650,7 @@ class Form extends Fieldset implements FormInterface
      * Set the input filter used by this form
      *
      * @param  InputFilterInterface $inputFilter
-     * @return FormInterface
+     * @return self
      */
     public function setInputFilter(InputFilterInterface $inputFilter)
     {
@@ -701,7 +704,7 @@ class Form extends Fieldset implements FormInterface
      * Set flag indicating whether or not to scan elements and fieldsets for defaults
      *
      * @param  bool $useInputFilterDefaults
-     * @return Form
+     * @return self
      */
     public function setUseInputFilterDefaults($useInputFilterDefaults)
     {
@@ -723,7 +726,7 @@ class Form extends Fieldset implements FormInterface
      * Set flag indicating whether or not to prefer the form input filter over element and fieldset defaults
      *
      * @param  bool $preferFormInputFilter
-     * @return Form
+     * @return self
      */
     public function setPreferFormInputFilter($preferFormInputFilter)
     {
@@ -761,9 +764,7 @@ class Form extends Fieldset implements FormInterface
         }
 
         if (!$fieldset instanceof Collection || !$fieldset->getTargetElement() instanceof FieldsetInterface || $inputFilter instanceof CollectionInputFilter) {
-            foreach ($elements as $element) {
-                $name = $element->getName();
-
+            foreach ($elements as $name => $element) {
                 if ($this->preferFormInputFilter && $inputFilter->has($name)) {
                     continue;
                 }
@@ -798,9 +799,7 @@ class Form extends Fieldset implements FormInterface
             }
         }
 
-        foreach ($fieldset->getFieldsets() as $childFieldset) {
-            $name = $childFieldset->getName();
-
+        foreach ($fieldset->getFieldsets() as $name => $childFieldset) {
             if (!$childFieldset instanceof InputFilterProviderInterface) {
                 if (!$inputFilter->has($name)) {
                     // Add a new empty input filter if it does not exist (or the fieldset's object input filter),
@@ -848,7 +847,7 @@ class Form extends Fieldset implements FormInterface
      * Are the form elements/fieldsets names wrapped by the form name ?
      *
      * @param  bool $wrapElements
-     * @return Form
+     * @return self
      */
     public function setWrapElements($wrapElements)
     {
@@ -867,7 +866,24 @@ class Form extends Fieldset implements FormInterface
     }
 
     /**
-     * Recursively extract values for elements and sub-fieldsets, and populate form values
+     * {@inheritDoc}
+     *
+     * @param bool $onlyBase
+     */
+    public function populateValues($data, $onlyBase = false)
+    {
+        if ($onlyBase && $this->baseFieldset !== null) {
+            $name = $this->baseFieldset->getName();
+            if (array_key_exists($name, $data)) {
+                $this->baseFieldset->populateValues($data[$name]);
+            }
+        } else {
+            parent::populateValues($data);
+        }
+    }
+
+    /**
+     * Recursively extract values for elements and sub-fieldsets
      *
      * @return array
      */
@@ -876,10 +892,8 @@ class Form extends Fieldset implements FormInterface
         if (null !== $this->baseFieldset) {
             $name = $this->baseFieldset->getName();
             $values[$name] = $this->baseFieldset->extract();
-            $this->baseFieldset->populateValues($values[$name]);
         } else {
             $values = parent::extract();
-            $this->populateValues($values);
         }
 
         return $values;
