@@ -189,10 +189,11 @@ class BaseInputFilter implements
     /**
      * Is the data set valid?
      *
+     * @param  mixed|null $context
      * @throws Exception\RuntimeException
      * @return bool
      */
-    public function isValid()
+    public function isValid($context = null)
     {
         $data = $this->getRawValues();
         if (null === $data) {
@@ -203,17 +204,18 @@ class BaseInputFilter implements
         }
 
         $inputs = $this->validationGroup ?: array_keys($this->inputs);
-        return $this->validateInputs($inputs, $data);
+        return $this->validateInputs($inputs, $data, $context);
     }
 
     /**
      * Validate a set of inputs against the current data
      *
-     * @param  array $inputs
-     * @param  array $data
+     * @param  array      $inputs
+     * @param  array      $data
+     * @param  mixed|null $context
      * @return bool
      */
-    protected function validateInputs(array $inputs, array $data = array())
+    protected function validateInputs(array $inputs, array $data = array(), $context = null)
     {
         // backwards compatibility
         if (empty($data)) {
@@ -226,109 +228,15 @@ class BaseInputFilter implements
 
         foreach ($inputs as $name) {
             $input      = $this->inputs[$name];
-            $dataExists = array_key_exists($name, $data);
 
-            // key doesn't exist, but input is not required; valid
-            if (!$dataExists
-                && $input instanceof InputInterface
-                && !$input->isRequired()
-            ) {
-                $this->validInputs[$name] = $input;
-                continue;
-            }
-
-            // key doesn't exist, input is required, allows empty; valid if
-            // continueIfEmpty is false or input doesn't implement
-            // that interface; otherwise validation chain continues
-            if (!$dataExists
-                && $input instanceof InputInterface
-                && $input->isRequired()
-                && $input->allowEmpty()
-            ) {
-                if (!($input instanceof EmptyContextInterface && $input->continueIfEmpty())) {
-                    $this->validInputs[$name] = $input;
-                    continue;
-                }
-            }
-
-            // key exists, is null, input is not required; valid
-            if ($dataExists
-                && null === $data[$name]
-                && $input instanceof InputInterface
-                && !$input->isRequired()
-            ) {
-                $this->validInputs[$name] = $input;
-                continue;
-            }
-
-            // key exists, is null, input is required, allows empty; valid if
-            // continueIfEmpty is false or input doesn't implement
-            // that interface; otherwise validation chain continues
-            if ($dataExists
-                && null === $data[$name]
-                && $input instanceof InputInterface
-                && $input->isRequired()
-                && $input->allowEmpty()
-            ) {
-                if (!($input instanceof EmptyContextInterface && $input->continueIfEmpty())) {
-                    $this->validInputs[$name] = $input;
-                    continue;
-                }
-            }
-
-            // key exists, empty string, input is not required, allows empty; valid
-            if ($dataExists
-                && '' === $data[$name]
-                && $input instanceof InputInterface
-                && !$input->isRequired()
-                && $input->allowEmpty()
-            ) {
-                $this->validInputs[$name] = $input;
-                continue;
-            }
-
-            // key exists, empty string, input is required, allows empty; valid
-            // if continueIfEmpty is false, otherwise validation continues
-            if ($dataExists
-                && '' === $data[$name]
-                && $input instanceof InputInterface
-                && $input->isRequired()
-                && $input->allowEmpty()
-            ) {
-                if (!($input instanceof EmptyContextInterface && $input->continueIfEmpty())) {
-                    $this->validInputs[$name] = $input;
-                    continue;
-                }
-            }
-
-            // key exists, is array representing file, no file present, input not
-            // required or allows empty; valid
-            if ($dataExists
-                && is_array($data[$name])
-                && (
-                    (isset($data[$name]['error'])
-                        && $data[$name]['error'] === UPLOAD_ERR_NO_FILE)
-                    || (count($data[$name]) === 1
-                        && isset($data[$name][0])
-                        && is_array($data[$name][0])
-                        && isset($data[$name][0]['error'])
-                        && $data[$name][0]['error'] === UPLOAD_ERR_NO_FILE)
-                )
-                && $input instanceof InputInterface
-                && (!$input->isRequired() || $input->allowEmpty())
-            ) {
-                $this->validInputs[$name] = $input;
-                continue;
-            }
-
-            // make sure we have a value (empty) for validation
-            if (!$dataExists) {
+            // make sure we have a value (empty) for validation of context
+            if (!array_key_exists($name, $data)) {
                 $data[$name] = null;
             }
 
             // Validate an input filter
             if ($input instanceof InputFilterInterface) {
-                if (!$input->isValid()) {
+                if (!$input->isValid($context)) {
                     $this->invalidInputs[$name] = $input;
                     $valid = false;
                     continue;
@@ -339,7 +247,9 @@ class BaseInputFilter implements
 
             // Validate an input
             if ($input instanceof InputInterface) {
-                if (!$input->isValid($data)) {
+                $inputContext = $context ?: $data;
+
+                if (!$input->isValid($inputContext)) {
                     // Validation failure
                     $this->invalidInputs[$name] = $input;
                     $valid = false;
@@ -531,6 +441,7 @@ class BaseInputFilter implements
                 $values[$name] = $input->getRawValues();
                 continue;
             }
+
             $values[$name] = $input->getRawValue();
         }
         return $values;
@@ -679,4 +590,18 @@ class BaseInputFilter implements
     {
         return $this->inputs;
     }
+
+    /**
+     * Merges the inputs from an InputFilter into the current one
+     *
+     * @param BaseInputFilter $inputFilter
+     *
+     * @return self
+     */
+    public function merge(BaseInputFilter $inputFilter)
+    {
+        foreach ($inputFilter->getInputs() as $name => $input) {
+            $this->add($input, $name);
+        }
+    }
 }
