@@ -445,10 +445,8 @@ class Dn implements ArrayAccess
             case self::ATTR_CASEFOLD_UPPER:
             case self::ATTR_CASEFOLD_LOWER:
                 return $caseFold;
-                break;
             default:
                 return $default;
-                break;
         }
     }
 
@@ -474,7 +472,7 @@ class Dn implements ArrayAccess
         foreach ($values as $key => $val) {
             // Escaping of filter meta characters
             $val = str_replace(
-                array('\\', ',', '+', '"', '<', '>', ';', '#', '=',),
+                array('\\', ',', '+', '"', '<', '>', ';', '#', '='),
                 array('\\\\', '\,', '\+', '\"', '\<', '\>', '\;', '\#', '\='), $val
             );
             $val = Converter\Converter::ascToHex32($val);
@@ -518,7 +516,7 @@ class Dn implements ArrayAccess
             // strip slashes from special chars
             $val          = str_replace(
                 array('\\\\', '\,', '\+', '\"', '\<', '\>', '\;', '\#', '\='),
-                array('\\', ',', '+', '"', '<', '>', ';', '#', '=',), $val
+                array('\\', ',', '+', '"', '<', '>', ';', '#', '=', ), $val
             );
             $values[$key] = Converter\Converter::hex32ToAsc($val);
         }
@@ -594,8 +592,6 @@ class Dn implements ArrayAccess
          * to state 1. If a backslash (\) is encountered, state 3 is used to collect the
          * following character without engaging the logic of other states.
          */
-        $key   = null;
-        $value = null;
         $slen  = strlen($dn);
         $state = 1;
         $ko    = $vo = 0;
