@@ -131,11 +131,6 @@ class PhpRenderer implements Renderer, TreeRendererInterface
      */
     private $__varsCache = array();
 
-    /**
-     * @var array Cache for the plugin call
-     */
-    private $__pluginCache = array();
-
     /**
      * Constructor.
      *
@@ -392,13 +387,13 @@ class PhpRenderer implements Renderer, TreeRendererInterface
      */
     public function __call($method, $argv)
     {
-        if (!isset($this->__pluginCache[$method])) {
-            $this->__pluginCache[$method] = $this->plugin($method);
+        $plugin = $this->plugin($method);
+
+        if (is_callable($plugin)) {
+            return call_user_func_array($plugin, $argv);
         }
-        if (is_callable($this->__pluginCache[$method])) {
-            return call_user_func_array($this->__pluginCache[$method], $argv);
-        }
-        return $this->__pluginCache[$method];
+
+        return $plugin;
     }
 
     /**
